@@ -118,8 +118,12 @@ class api {
                         $langs = $stringmanager->get_list_of_translations(true);
                         foreach ($langs as $langid => $langname) {
                             foreach ($addoninfo['lang'] as $stringinfo) {
-                                $lang[$langid][$stringinfo[0]] =
-                                    $stringmanager->get_string($stringinfo[0], $stringinfo[1], null, $langid);
+                                $lang[$langid][$stringinfo[0]] = $stringmanager->get_string(
+                                    $stringinfo[0],
+                                    $stringinfo[1] ?? '',
+                                    null,
+                                    $langid
+                                );
                             }
                         }
                     }
@@ -167,6 +171,9 @@ class api {
         // We need this to make work the format text functions.
         $PAGE->set_context($context);
 
+        // Check if contacting site support is available to all visitors.
+        $sitesupportavailable = (isset($CFG->supportavailability) && $CFG->supportavailability == CONTACT_SUPPORT_ANYONE);
+
         list($authinstructions, $notusedformat) = external_format_text($CFG->auth_instructions, FORMAT_MOODLE, $context->id);
         list($maintenancemessage, $notusedformat) = external_format_text($CFG->maintenance_message, FORMAT_MOODLE, $context->id);
         $settings = array(
@@ -198,7 +205,8 @@ class api {
             'tool_mobile_androidappid' => get_config('tool_mobile', 'androidappid'),
             'tool_mobile_setuplink' => clean_param(get_config('tool_mobile', 'setuplink'), PARAM_URL),
             'tool_mobile_qrcodetype' => clean_param(get_config('tool_mobile', 'qrcodetype'), PARAM_INT),
-            'supportpage' => clean_param($CFG->supportpage, PARAM_URL),
+            'supportpage' => $sitesupportavailable ? clean_param($CFG->supportpage, PARAM_URL) : '',
+            'supportavailability' => clean_param($CFG->supportavailability, PARAM_INT),
         );
 
         $typeoflogin = get_config('tool_mobile', 'typeoflogin');
@@ -236,8 +244,8 @@ class api {
             }
         }
 
-        // If age is verified, return also the admin contact details.
-        if ($settings['agedigitalconsentverification']) {
+        // If age is verified or support is available to all visitors, also return the admin contact details.
+        if ($settings['agedigitalconsentverification'] || $sitesupportavailable) {
             $settings['supportname'] = clean_param($CFG->supportname, PARAM_NOTAGS);
             $settings['supportemail'] = clean_param($CFG->supportemail, PARAM_EMAIL);
         }
@@ -330,9 +338,17 @@ class api {
         }
 
         if (empty($section) or $section == 'supportcontact') {
-            $settings->supportname = $CFG->supportname;
-            $settings->supportemail = $CFG->supportemail ?? null;
-            $settings->supportpage = $CFG->supportpage;
+            $settings->supportavailability = $CFG->supportavailability;
+
+            if ($CFG->supportavailability == CONTACT_SUPPORT_DISABLED) {
+                $settings->supportname = null;
+                $settings->supportemail = null;
+                $settings->supportpage = null;
+            } else {
+                $settings->supportname = $CFG->supportname;
+                $settings->supportemail = $CFG->supportemail ?? null;
+                $settings->supportpage = $CFG->supportpage;
+            }
         }
 
         if (empty($section) || $section === 'graceperiodsettings') {
@@ -344,6 +360,10 @@ class api {
             $settings->enabledashboard = $CFG->enabledashboard;
         }
 
+        if (empty($section) || $section === 'themesettings') {
+            $settings->customusermenuitems = $CFG->customusermenuitems;
+        }
+
         return $settings;
     }
 
@@ -399,13 +419,13 @@ class api {
     public static function get_qrlogin_key(stdClass $mobilesettings) {
         global $USER;
         // Delete previous keys.
-        delete_user_key('tool_mobile', $USER->id);
+        delete_user_key('tool_mobile/qrlogin', $USER->id);
 
         // Create a new key.
-        $iprestriction = getremoteaddr(null);
+        $iprestriction = !empty($mobilesettings->qrsameipcheck) ? getremoteaddr(null) : null;
         $qrkeyttl = !empty($mobilesettings->qrkeyttl) ? $mobilesettings->qrkeyttl : self::LOGIN_QR_KEY_TTL;
         $validuntil = time() + $qrkeyttl;
-        return create_user_key('tool_mobile', $USER->id, null, $iprestriction, $validuntil);
+        return create_user_key('tool_mobile/qrlogin', $USER->id, null, $iprestriction, $validuntil);
     }
 
     /**
@@ -504,6 +524,8 @@ class api {
                 'NoDelegate_H5POffline' => new lang_string('h5poffline', 'tool_mobile'),
                 'NoDelegate_DarkMode' => new lang_string('darkmode', 'tool_mobile'),
                 'CoreFilterDelegate' => new lang_string('type_filter_plural', 'plugin'),
+                'CoreReportBuilderDelegate' => new lang_string('reportbuilder', 'core_reportbuilder'),
+                'NoDelegate_CoreUserSupport' => new lang_string('contactsitesupport', 'admin'),
             ),
             "$mainmenu" => array(
                 '$mmSideMenuDelegate_mmaFrontpage' => new lang_string('sitehome'),
