@@ -36,7 +36,7 @@ $string['asyncemailenable'] = 'Enable message notifications';
 $string['asyncemailenabledetail'] = 'If enabled, users will receive a message when an asynchronous backup or restore completes.';
 $string['asyncmessagebody'] = 'Message';
 $string['asyncmessagebodydetail'] = 'Message to send when an asynchronous backup or restore completes.';
-$string['asyncmessagebodydefault'] = 'Hi {user_firstname},<br/> Your {operation} (ID: {backupid}) has completed successfully. <br/><br/>You can access it here: {link}.';
+$string['asyncmessagebodydefault'] = 'Your {operation} (ID: {backupid}) has completed successfully. You can access it here: <a href="{link}">{link}</a>.';
 $string['asyncmessagesubject'] = 'Subject';
 $string['asyncmessagesubjectdetail'] = 'Message subject';
 $string['asyncmessagesubjectdefault'] = 'Moodle {operation} completed successfully';
@@ -70,6 +70,7 @@ $string['automatedsettings'] = 'Automated backup settings';
 $string['automatedstorage'] = 'Automated backup storage';
 $string['automatedstoragehelp'] = 'Choose the location where you want backups to be stored when they are automatically created.';
 $string['backupactivity'] = 'Backup activity: {$a}';
+$string['backupautoactivitiesdescription'] = 'Sets the default for including activities in a backup. For the recycle bin to work, this setting must be enabled.';
 $string['backupcourse'] = 'Backup course: {$a}';
 $string['backupcoursedetails'] = 'Course details';
 $string['backupcoursesection'] = 'Section: {$a}';
@@ -172,7 +173,7 @@ $string['copycoursetitle'] = 'Copy course: {$a}';
 $string['copydest'] = 'Destination';
 $string['copyingcourse'] = 'Course copying in progress';
 $string['copyingcourseshortname'] = 'copying';
-$string['copyfieldnotfound'] = 'A required field was not found';
+$string['copyfieldnotfound'] = 'Required field data was not found for field(s): {$a}';
 $string['copyformfail'] = 'AJAX submission of course copy form has failed.';
 $string['copyop'] = 'Current operation';
 $string['copyprogressheading'] = 'Course copies in progress';
@@ -305,12 +306,12 @@ $string['privacy:metadata:backup_controllers:type'] = 'The type of the item bein
 $string['qcategory2coursefallback'] = 'The questions category "{$a->name}", originally at system/course category context in backup file, will be created at course context by restore';
 $string['qcategorycannotberestored'] = 'The questions category "{$a->name}" cannot be created by restore';
 $string['question2coursefallback'] = 'The questions category "{$a->name}", originally at system/course category context in backup file, will be created at course context by restore';
-$string['questionegorycannotberestored'] = 'The questions "{$a->name}" cannot be created by restore';
+$string['questioncannotberestored'] = 'The questions "{$a->name}" cannot be created by restore';
 $string['restoreactivity'] = 'Restore activity';
 $string['restorecourse'] = 'Restore course';
 $string['restorecoursesettings'] = 'Course settings';
 $string['restoredcourseid'] = 'Restored course ID: {$a}';
-$string['restoreexecutionsuccess'] = 'The course was restored successfully, clicking the continue button below will take you to view the course you restored.';
+$string['restoreexecutionsuccess'] = 'The course was successfully restored.';
 $string['restorefileweremissing'] = 'Some files could not be restored because they were missing in the backup.';
 $string['restorenewcoursefullname'] = 'New course name';
 $string['restorenewcourseshortname'] = 'New course short name';
@@ -412,4 +413,4 @@ $string['userdata_help'] = 'If enabled, data such as forum posts, assignment sub
 $string['userinfo'] = 'Userinfo';
 $string['module'] = 'Module';
 $string['morecoursesearchresults'] = 'More than {$a} courses found, showing first {$a} results';
-$string['recyclebin_desc'] = 'Note that these settings will be also be used for the recycle bin.';
+$string['recyclebin_desc'] = 'Note that these settings will also be used for the recycle bin.';
