@@ -58,6 +58,7 @@ $string['cannotmovequestion'] = 'You can\'t use this script to move questions th
 $string['cannotopenforwriting'] = 'Cannot open for writing: {$a}';
 $string['cannotpreview'] = 'You can\'t preview these questions!';
 $string['cannotread'] = 'Cannot read import file (or file is empty)';
+$string['cannotregradedifferentqtype'] = 'Cannot regrade with a question of a different type.';
 $string['cannotretrieveqcat'] = 'Could not retrieve question category';
 $string['cannotunhidequestion'] = 'Failed to unhide the question.';
 $string['cannotunzip'] = 'Could not unzip file.';
@@ -99,8 +100,13 @@ $string['defaultfor'] = 'Default for {$a}';
 $string['defaultinfofor'] = 'The default category for questions shared in context \'{$a}\'.';
 $string['defaultmarkmustbepositive'] = 'The default mark must be positive.';
 $string['deletecoursecategorywithquestions'] = 'There are questions in the question bank associated with this course category. If you proceed, they will be deleted. You may wish to move them first, using the question bank interface.';
-$string['deletequestioncheck'] = 'Are you absolutely sure you want to delete \'{$a}\'?';
-$string['deletequestionscheck'] = 'Are you absolutely sure you want to delete the following questions?<br /><br />{$a}';
+$string['deletequestioncheck'] = 'This will delete the following question and all its versions:<br /><br />{$a}';
+$string['deletequestionscheck'] = 'This will delete the following questions and all their versions:<br /><br />{$a}';
+$string['deleteselectedquestioncheck'] = 'This will delete selected versions of the following question:<br /><br />{$a}';
+$string['deletequestiontitle'] = 'Delete question?';
+$string['deletequestiontitle_plural'] = 'Delete questions?';
+$string['deleteversiontitle'] = 'Delete selected version?';
+$string['deleteversiontitle_plural'] = 'Delete selected versions?';
 $string['deletingbehaviour'] = 'Deleting question behaviour \'{$a}\'';
 $string['deletingqtype'] = 'Deleting question type \'{$a}\'';
 $string['didnotmatchanyanswer'] = '[Did not match any answer]';
@@ -202,6 +208,7 @@ $string['importparseerror'] = 'Error(s) found parsing the import file. No questi
 $string['importquestions'] = 'Import questions from file';
 $string['importquestions_help'] = 'This function enables questions in a variety of formats to be imported via text file. Note that the file must use UTF-8 encoding.';
 $string['importquestions_link'] = 'question/import';
+$string['importwrongfileencoding'] = 'The file you selected does not use UTF-8 character encoding. {$a} files must use UTF-8.';
 $string['importwrongfiletype'] = 'The type of the file you selected ({$a->actualtype}) does not match the type expected by this import format ({$a->expectedtype}).';
 $string['invalidarg'] = 'No valid arguments supplied or incorrect server configuration';
 $string['invalidcategoryidforparent'] = 'Invalid category id for parent!';
@@ -235,7 +242,7 @@ $string['movedquestionsandcategories'] = 'Moved questions and question categorie
 $string['movelinksonly'] = 'Just change where links point to, do not move or copy files.';
 $string['moveq'] = 'Move question(s)';
 $string['moveqtoanothercontext'] = 'Move question to another context.';
-$string['moveto'] = 'Move to >>';
+$string['moveto'] = 'Move to';
 $string['movingcategory'] = 'Moving category';
 $string['movingcategoryandfiles'] = 'Are you sure you want to move category {$a->name} and all child categories to context for "{$a->contextto}"?<br /> We have detected {$a->urlcount} files linked from questions in {$a->fromareaname}, would you like to copy or move these to {$a->toareaname}?';
 $string['movingcategorynofiles'] = 'Are you sure you want to move category "{$a->name}" and all child categories to context for "{$a->contextto}"?';
@@ -245,7 +252,7 @@ $string['movingquestionsnofiles'] = 'Are you sure you want to move question(s) {
 $string['needtochoosecat'] = 'You need to choose a category to move this question to or press \'cancel\'.';
 $string['nocate'] = 'No such category {$a}!';
 $string['nopermissionadd'] = 'You don\'t have permission to add questions here.';
-$string['nopermissionmove'] = 'You don\'t have permission to move questions from here. You must save the question in this category or save it as a new question.';
+$string['nopermissionedit'] = 'You don\'t have permission to edit questions from here.';
 $string['noprobs'] = 'No problems found in your question database.';
 $string['noquestions'] = 'No questions were found that could be exported. Make sure that you have selected a category to export that contains questions.';
 $string['noquestionsinfile'] = 'There are no questions in the import file';
@@ -253,11 +260,10 @@ $string['notagfiltersapplied'] = 'No tag filters applied';
 $string['notenoughanswers'] = 'This type of question requires at least {$a} answers';
 $string['notenoughdatatoeditaquestion'] = 'Neither a question id, nor a category id and question type, was specified.';
 $string['notenoughdatatomovequestions'] = 'You need to provide the question ids of questions you want to move.';
-$string['notflagged'] = 'Not flagged';
 $string['novirtualquestiontype'] = 'No virtual question type for question type {$a}';
 $string['numqas'] = 'No. question attempts';
 $string['numquestions'] = 'No. questions';
-$string['numquestionsandhidden'] = '{$a->numquestions} (+{$a->numhidden} hidden)';
+$string['numquestionsandhidden'] = '{$a->numquestions} (+{$a->numhidden} hidden +{$a->numdraft} draft)';
 $string['page-question-x'] = 'Any question page';
 $string['page-question-edit'] = 'Question editing page';
 $string['page-question-category'] = 'Question category page';
@@ -281,13 +287,16 @@ $string['published'] = 'shared';
 $string['qtypeveryshort'] = 'T';
 $string['questionaffected'] = '<a href="{$a->qurl}">Question "{$a->name}" ({$a->qtype})</a> is in this question category but is also being used in <a href="{$a->qurl}">quiz "{$a->quizname}"</a> in another course "{$a->coursename}".';
 $string['questionbank'] = 'Question bank';
+$string['questionbanknavigation'] = 'Question bank tertiary navigation';
+$string['questioncategories'] = 'Question categories';
 $string['questioncategory'] = 'Question category';
 $string['questioncatsfor'] = 'Question categories for \'{$a}\'';
 $string['questiondoesnotexist'] = 'This question does not exist';
 $string['questionname'] = 'Question name';
+$string['questionnameandquestionversion'] = '{$a->name} v{$a->version}';
 $string['questionno'] = 'Question {$a}';
 $string['questionsaveerror'] = 'Errors occur during saving question - ({$a})';
-$string['questionsinuse'] = '(* Questions marked with an asterisk are used somewhere, for example in a quiz. Therefore, if you proceed, these questions will not really be deleted, they will just be hidden.)';
+$string['questionsinuse'] = '* Denotes questions which can\'t be deleted because they are in use. Instead, they will be hidden in the question bank unless you select \'Show old questions\'.';
 $string['questionsmovedto'] = 'Questions still in use moved to "{$a}" in the parent course category.';
 $string['questionsrescuedfrom'] = 'Questions saved from context {$a}.';
 $string['questionsrescuedfrominfo'] = 'These questions (some of which may be hidden) were saved when context {$a} was deleted because they are still used by some quizzes or other activities.';
@@ -326,8 +335,9 @@ $string['action'] = 'Action';
 $string['addanotherhint'] = 'Add another hint';
 $string['answer'] = 'Answer';
 $string['answersaved'] = 'Answer saved';
+$string['answerx'] = 'Answer {$a}';
 $string['attemptfinished'] = 'Attempt finished';
-$string['attemptfinishedsubmitting'] = 'Attempt finished submitting: ';
+$string['attemptfinishedsubmitting'] = 'Attempt finished submitting: {$a}';
 $string['behaviourbeingused'] = 'Behaviour being used: {$a}';
 $string['cannotloadquestion'] = 'Could not load question';
 $string['cannotpreview'] = 'You can\'t preview these questions!';
@@ -353,9 +363,9 @@ $string['decimalplacesingrades'] = 'Decimal places in grades';
 $string['defaultmark'] = 'Default mark';
 $string['errorsavingflags'] = 'Error saving the flag state.';
 $string['feedback'] = 'Feedback';
+$string['fieldinquestion'] = '{$a->fieldname} {$a->questionindentifier}';
+$string['fieldinquestionpre'] = '{$a->questionindentifier} {$a->fieldname}';
 $string['fillincorrect'] = 'Fill in correct responses';
-$string['flagged'] = 'Flagged';
-$string['flagthisquestion'] = 'Flag this question';
 $string['generalfeedback'] = 'General feedback';
 $string['generalfeedback_help'] = 'General feedback is shown to the student after they have completed the question. Unlike specific feedback, which depends on the question type and what response the student gave, the same general feedback text is shown to all students.
 
@@ -388,7 +398,6 @@ $string['markoutofmax'] = 'Mark {$a->mark} out of {$a->max}';
 $string['marks'] = 'Marks';
 $string['noresponse'] = '[No response]';
 $string['notanswered'] = 'Not answered';
-$string['notflagged'] = 'Not flagged';
 $string['notgraded'] = 'Not graded';
 $string['notshown'] = 'Not shown';
 $string['notyetanswered'] = 'Not yet answered';
@@ -426,6 +435,8 @@ $string['privacy:metadata:database:question_attempts'] = 'The information about
 $string['privacy:metadata:database:question_attempts:flagged'] = 'An indication that the user has flagged this question within the attempt.';
 $string['privacy:metadata:database:question_attempts:responsesummary'] = 'A summary of the question response.';
 $string['privacy:metadata:database:question_attempts:timemodified'] = 'The time that the question attempt was updated.';
+$string['privacy:metadata:database:question_bank_entries'] = 'The details about a specific question bank entry.';
+$string['privacy:metadata:database:question_bank_entries:ownerid'] = 'The person who owns the question bank entry.';
 $string['privacy:metadata:link:qbehaviour'] = 'The Question subsystem makes use of the Question Behaviour plugintype.';
 $string['privacy:metadata:link:qformat'] = 'The Question subsystem makes use of the Question Format plugintype for the purpose of importing and exporting questions in different formats.';
 $string['privacy:metadata:link:qtype'] = 'The Question subsystem interacts with the Question Type plugintype which contains the different types of questions.';
@@ -451,12 +462,14 @@ $string['restoremultipletopcats'] = 'The backup file contains more than one top-
 $string['rightanswer'] = 'Right answer';
 $string['rightanswer_help'] = 'An automatically generated summary of the correct response. This can be limited, so you may wish to consider explaining the correct solution in the general feedback for the question, and turning this option off.';
 $string['saved'] = 'Saved: {$a}';
-$string['saveflags'] = 'Save the state of the flags';
 $string['settingsformultipletries'] = 'Multiple tries';
 $string['showhidden'] = 'Also show old questions';
 $string['showmarkandmax'] = 'Show mark and max';
 $string['showmaxmarkonly'] = 'Show max mark only';
-$string['showquestiontext'] = 'Show question text in the question list';
+$string['showquestiontext'] = 'Show question text in the question list?';
+$string['showquestiontext_full'] = 'Yes, with images, media, etc.';
+$string['showquestiontext_off'] = 'No';
+$string['showquestiontext_plain'] = 'Yes, text only';
 $string['shown'] = 'Shown';
 $string['shownumpartscorrect'] = 'Show the number of correct responses';
 $string['shownumpartscorrectwhenfinished'] = 'Show the number of correct responses once the question has finished';
@@ -494,3 +507,14 @@ $string['whichtries'] = 'Which tries';
 $string['withselected'] = 'With selected';
 $string['xoutofmax'] = '{$a->mark} out of {$a->max}';
 $string['yougotnright'] = 'You have correctly selected {$a->num}.';
+$string['qbanknotfound'] = 'The \'{$a}\' question bank plugin doesn\'t exist or is not recognised.';
+$string['noquestionbanks'] = 'No question bank plugin found.';
+$string['questionloaderror'] = 'Could not load the question options.';
+$string['version_selection'] = 'Version {$a->version}';
+$string['question_version'] = 'Question version';
+
+// Deprecated since Moodle 4.0.
+$string['notflagged'] = 'Not flagged';
+
+// Deprecated since Moodle 4.1.
+$string['nopermissionmove'] = 'You don\'t have permission to move questions from here. You must save the question in this category or save it as a new question.';
