@@ -156,12 +156,24 @@ class behat_core_generator extends behat_generator_base {
                 'datagenerator' => 'role',
                 'required' => ['shortname'],
             ],
+            'role capabilities' => [
+                'singular' => 'role capability',
+                'datagenerator' => 'role_capability',
+                'required' => ['role'],
+                'switchids' => ['role' => 'roleid'],
+            ],
             'grade categories' => [
                 'singular' => 'grade category',
                 'datagenerator' => 'grade_category',
                 'required' => ['fullname', 'course'],
                 'switchids' => ['course' => 'courseid', 'gradecategory' => 'parent'],
             ],
+            'grade grades' => [
+                'singular' => 'grade grade',
+                'datagenerator' => 'grade_grade',
+                'required' => ['gradeitem'],
+                'switchids' => ['user' => 'userid', 'gradeitem' => 'itemid'],
+            ],
             'grade items' => [
                 'singular' => 'grade item',
                 'datagenerator' => 'grade_item',
@@ -253,6 +265,11 @@ class behat_core_generator extends behat_generator_base {
                 'datagenerator' => 'customlang',
                 'required' => ['component', 'stringid', 'value'],
             ],
+            'language packs' => [
+                'singular' => 'language pack',
+                'datagenerator' => 'langpack',
+                'required' => ['language'],
+            ],
             'analytics models' => [
                 'singular' => 'analytics model',
                 'datagenerator' => 'analytics_model',
@@ -270,6 +287,12 @@ class behat_core_generator extends behat_generator_base {
                 'required' => array('contextlevel', 'reference', 'contenttype', 'user', 'contentname'),
                 'switchids' => array('user' => 'userid')
             ],
+            'user private files' => [
+                'singular' => 'user private file',
+                'datagenerator' => 'user_private_files',
+                'required' => ['user', 'filepath'],
+                'switchids' => ['user' => 'userid']
+            ],
             'badge external backpacks' => [
                 'singular' => 'badge external backpack',
                 'datagenerator' => 'badge_external_backpack',
@@ -287,11 +310,33 @@ class behat_core_generator extends behat_generator_base {
                 'required' => ['user', 'course', 'lastaccess'],
                 'switchids' => ['user' => 'userid', 'course' => 'courseid'],
             ],
+            'notifications' => [
+                'singular' => 'notification',
+                'datagenerator' => 'notification',
+                'required' => ['subject', 'userfrom', 'userto'],
+                'switchids' => ['userfrom' => 'userfromid', 'userto' => 'usertoid'],
+            ],
         ];
 
         return $entities;
     }
 
+    /**
+     * Get the grade item id using a name.
+     *
+     * @param string $name
+     * @return int The grade item id
+     */
+    protected function get_gradeitem_id(string $name): int {
+        global $DB;
+
+        if (!$id = $DB->get_field('grade_items', 'id', ['itemname' => $name])) {
+            throw new Exception('The specified grade item with name "' . $name . '" could not be found.');
+        }
+
+        return $id;
+    }
+
     /**
      * Remove any empty custom fields, to avoid errors when creating the course.
      *
@@ -425,13 +470,7 @@ class behat_core_generator extends behat_generator_base {
             }
         }
 
-        // Custom exception.
-        try {
-            $this->datagenerator->create_module($activityname, $data, $cmoptions);
-        } catch (coding_exception $e) {
-            throw new Exception('\'' . $activityname . '\' activity can not be added using this step,' .
-                    ' use the step \'I add a "ACTIVITY_OR_RESOURCE_NAME_STRING" to section "SECTION_NUMBER"\' instead');
-        }
+        $this->datagenerator->create_module($activityname, $data, $cmoptions);
     }
 
     /**
@@ -521,6 +560,16 @@ class behat_core_generator extends behat_generator_base {
             tool_customlang_utils::checkin($USER->lang);
         }
     }
+    /**
+     * Imports a langpack.
+     *
+     * @param array $data
+     */
+    protected function process_langpack($data) {
+        $controller = new \tool_langimport\controller();
+        $controller->install_languagepacks($data['language']);
+        get_string_manager()->reset_caches();
+    }
 
     /**
      * Adapter to enrol_user() data generator.
@@ -558,6 +607,16 @@ class behat_core_generator extends behat_generator_base {
 
         if (!isset($data['status'])) {
             $data['status'] = null;
+        } else {
+            $status = strtolower($data['status']);
+            switch ($status) {
+                case 'active':
+                    $data['status'] = ENROL_USER_ACTIVE;
+                    break;
+                case 'suspended':
+                    $data['status'] = ENROL_USER_SUSPENDED;
+                    break;
+            }
         }
 
         // If the provided course shortname is the site shortname we consider it a system role assign.
@@ -681,6 +740,23 @@ class behat_core_generator extends behat_generator_base {
         $this->datagenerator->create_role($data);
     }
 
+    /**
+     * Assign capabilities to a role.
+     *
+     * @param array $data
+     */
+    protected function process_role_capability($data): void {
+        // We require the user to fill the role shortname.
+        if (empty($data['roleid'])) {
+            throw new Exception('\'role capability\' requires the field \'roleid\' to be specified');
+        }
+
+        $roleid = $data['roleid'];
+        unset($data['roleid']);
+
+        $this->datagenerator->create_role_capability($roleid, $data, \context_system::instance());
+    }
+
     /**
      * Adds members to cohorts
      *
@@ -988,6 +1064,34 @@ class behat_core_generator extends behat_generator_base {
         }
     }
 
+    /**
+     * Create content in the given user's private files.
+     *
+     * @param array $data
+     * @return void
+     */
+    protected function process_user_private_files(array $data) {
+        global $CFG;
+
+        $userid = $data['userid'];
+        $fs = get_file_storage();
+        $filepath = "{$CFG->dirroot}/{$data['filepath']}";
+
+        if (!file_exists($filepath)) {
+            throw new coding_exception("File '{$filepath}' does not exist");
+        }
+        $filerecord = [
+            'userid' => $userid,
+            'contextid' => context_user::instance($userid)->id,
+            'component' => 'user',
+            'filearea' => 'private',
+            'itemid' => 0,
+            'filepath'  => '/',
+            'filename'  => basename($filepath),
+        ];
+        $fs->create_file_from_pathname($filerecord, $filepath);
+    }
+
     /**
      * Create a exetrnal backpack.
      *
@@ -1040,6 +1144,39 @@ class behat_core_generator extends behat_generator_base {
         $DB->insert_record('badge_backpack', $backpack);
     }
 
+    /**
+     * Creates notifications to specific user.
+     *
+     * @param array $data
+     * @return void
+     */
+    protected function process_notification(array $data) {
+        global $DB;
+
+        $notification = new stdClass();
+        $notification->useridfrom = $data['userfromid'];
+        $notification->useridto = $data['usertoid'];
+        $notification->subject = $data['subject'];
+        $notification->fullmessage = $data['subject'] . ' description';
+        $notification->smallmessage = $data['subject'] . ' description';
+        $notification->fullmessagehtml = $data['subject'] . ' description';
+
+        if ($data['timecreated'] !== 'null') {
+            $notification->timecreated = $data['timecreated'];
+        }
+
+        if ($data['timeread'] !== 'null') {
+            $notification->timeread = $data['timeread'];
+        }
+
+        if (!empty($data)) {
+            $popupnotification = new stdClass();
+            $popupnotification->notificationid = $DB->insert_record('notifications', $notification);
+            $DB->insert_record('message_popup_notifications', $popupnotification);
+        }
+
+    }
+
     /**
      * Creates user last access data within given courses.
      *
