@@ -41,10 +41,49 @@ abstract class scheduled_task extends task_base {
     /** Maximum hour value. */
     const HOURMAX = 23;
 
+    /** Minimum day of month value. */
+    const DAYMIN = 1;
+    /** Maximum day of month value. */
+    const DAYMAX = 31;
+
+    /** Minimum month value. */
+    const MONTHMIN = 1;
+    /** Maximum month value. */
+    const MONTHMAX = 12;
+
     /** Minimum dayofweek value. */
     const DAYOFWEEKMIN = 0;
     /** Maximum dayofweek value. */
     const DAYOFWEEKMAX = 6;
+    /** Maximum dayofweek value allowed in input (7 = 0). */
+    const DAYOFWEEKMAXINPUT = 7;
+
+    /**
+     * Minute field identifier.
+     */
+    const FIELD_MINUTE = 'minute';
+    /**
+     * Hour field identifier.
+     */
+    const FIELD_HOUR = 'hour';
+    /**
+     * Day-of-month field identifier.
+     */
+    const FIELD_DAY = 'day';
+    /**
+     * Month field identifier.
+     */
+    const FIELD_MONTH = 'month';
+    /**
+     * Day-of-week field identifier.
+     */
+    const FIELD_DAYOFWEEK = 'dayofweek';
+
+    /**
+     * Time used for the next scheduled time when a task should never run. This is 2222-01-01 00:00 GMT
+     * which is a large time that still fits in 10 digits.
+     */
+    const NEVER_RUN_TIME = 7952342400;
 
     /** @var string $hour - Pattern to work out the valid hours */
     private $hour = '*';
@@ -75,6 +114,7 @@ abstract class scheduled_task extends task_base {
 
     /**
      * Get the last run time for this scheduled task.
+     *
      * @return int
      */
     public function get_last_run_time() {
@@ -83,6 +123,7 @@ abstract class scheduled_task extends task_base {
 
     /**
      * Set the last run time for this scheduled task.
+     *
      * @param int $lastruntime
      */
     public function set_last_run_time($lastruntime) {
@@ -91,6 +132,7 @@ abstract class scheduled_task extends task_base {
 
     /**
      * Has this task been changed from it's default config?
+     *
      * @return bool
      */
     public function is_customised() {
@@ -99,6 +141,7 @@ abstract class scheduled_task extends task_base {
 
     /**
      * Has this task been changed from it's default config?
+     *
      * @param bool
      */
     public function set_customised($customised) {
@@ -107,6 +150,7 @@ abstract class scheduled_task extends task_base {
 
     /**
      * Has this task been changed from it's default config?
+     *
      * @return bool
      */
     public function is_overridden(): bool {
@@ -115,6 +159,7 @@ abstract class scheduled_task extends task_base {
 
     /**
      * Set the overridden value.
+     *
      * @param bool $overridden
      */
     public function set_overridden(bool $overridden): void {
@@ -124,6 +169,7 @@ abstract class scheduled_task extends task_base {
     /**
      * Setter for $minute. Accepts a special 'R' value
      * which will be translated to a random minute.
+     *
      * @param string $minute
      * @param bool $expandr - if true (default) an 'R' value in a time is expanded to an appropriate int.
      *      If false, they are left as 'R'
@@ -137,6 +183,7 @@ abstract class scheduled_task extends task_base {
 
     /**
      * Getter for $minute.
+     *
      * @return string
      */
     public function get_minute() {
@@ -146,6 +193,7 @@ abstract class scheduled_task extends task_base {
     /**
      * Setter for $hour. Accepts a special 'R' value
      * which will be translated to a random hour.
+     *
      * @param string $hour
      * @param bool $expandr - if true (default) an 'R' value in a time is expanded to an appropriate int.
      *      If false, they are left as 'R'
@@ -159,6 +207,7 @@ abstract class scheduled_task extends task_base {
 
     /**
      * Getter for $hour.
+     *
      * @return string
      */
     public function get_hour() {
@@ -167,6 +216,7 @@ abstract class scheduled_task extends task_base {
 
     /**
      * Setter for $month.
+     *
      * @param string $month
      */
     public function set_month($month) {
@@ -175,6 +225,7 @@ abstract class scheduled_task extends task_base {
 
     /**
      * Getter for $month.
+     *
      * @return string
      */
     public function get_month() {
@@ -183,6 +234,7 @@ abstract class scheduled_task extends task_base {
 
     /**
      * Setter for $day.
+     *
      * @param string $day
      */
     public function set_day($day) {
@@ -191,6 +243,7 @@ abstract class scheduled_task extends task_base {
 
     /**
      * Getter for $day.
+     *
      * @return string
      */
     public function get_day() {
@@ -199,6 +252,7 @@ abstract class scheduled_task extends task_base {
 
     /**
      * Setter for $dayofweek.
+     *
      * @param string $dayofweek
      * @param bool $expandr - if true (default) an 'R' value in a time is expanded to an appropriate int.
      *      If false, they are left as 'R'
@@ -212,6 +266,7 @@ abstract class scheduled_task extends task_base {
 
     /**
      * Getter for $dayofweek.
+     *
      * @return string
      */
     public function get_day_of_week() {
@@ -220,6 +275,7 @@ abstract class scheduled_task extends task_base {
 
     /**
      * Setter for $disabled.
+     *
      * @param bool $disabled
      */
     public function set_disabled($disabled) {
@@ -243,6 +299,69 @@ abstract class scheduled_task extends task_base {
         return false;
     }
 
+    /**
+     * Informs whether the given field is valid.
+     * Use the constants FIELD_* to identify the field.
+     * Have to be called after the method set_{field}(string).
+     *
+     * @param string $field field identifier; expected values from constants FIELD_*.
+     *
+     * @return bool true if given field is valid. false otherwise.
+     */
+    public function is_valid(string $field): bool {
+        return !empty($this->get_valid($field));
+    }
+
+    /**
+     * Calculates the list of valid values according to the given field and stored expression.
+     *
+     * @param string $field field identifier. Must be one of those FIELD_*.
+     *
+     * @return array(int) list of matching values.
+     *
+     * @throws \coding_exception when passed an invalid field identifier.
+     */
+    private function get_valid(string $field): array {
+        switch($field) {
+            case self::FIELD_MINUTE:
+                $min = self::MINUTEMIN;
+                $max = self::MINUTEMAX;
+                break;
+            case self::FIELD_HOUR:
+                $min = self::HOURMIN;
+                $max = self::HOURMAX;
+                break;
+            case self::FIELD_DAY:
+                $min = self::DAYMIN;
+                $max = self::DAYMAX;
+                break;
+            case self::FIELD_MONTH:
+                $min = self::MONTHMIN;
+                $max = self::MONTHMAX;
+                break;
+            case self::FIELD_DAYOFWEEK:
+                $min = self::DAYOFWEEKMIN;
+                $max = self::DAYOFWEEKMAXINPUT;
+                break;
+            default:
+                throw new \coding_exception("Field '$field' is not a valid crontab identifier.");
+        }
+
+        $result = $this->eval_cron_field($this->{$field}, $min, $max);
+        if ($field === self::FIELD_DAYOFWEEK) {
+            // For day of week, 0 and 7 both mean Sunday; if there is a 7 we set 0. The result array is sorted.
+            if (end($result) === 7) {
+                // Remove last element.
+                array_pop($result);
+                // Insert 0 as first element if it's not there already.
+                if (reset($result) !== 0) {
+                    array_unshift($result, 0);
+                }
+            }
+        }
+        return $result;
+    }
+
     /**
      * Take a cron field definition and return an array of valid numbers with the range min-max.
      *
@@ -272,7 +391,6 @@ abstract class scheduled_task extends task_base {
         $last = 0;
         $inrange = false;
         $instep = false;
-
         foreach ($matches[0] as $match) {
             if ($match == '*') {
                 array_push($range, range($min, $max));
@@ -281,28 +399,40 @@ abstract class scheduled_task extends task_base {
             } else if ($match == '-') {
                 $inrange = true;
             } else if (is_numeric($match)) {
+                if ($min > $match || $match > $max) {
+                    // This is a value error: The value lays out of the expected range of values.
+                    return [];
+                }
                 if ($instep) {
-                    $i = 0;
+                    // Normalise range property, account for "5/10".
+                    $insteprange = $range[count($range) - 1];
+                    if (!is_array($insteprange)) {
+                        $range[count($range) - 1] = range($insteprange, $max);
+                    }
                     for ($i = 0; $i < count($range[count($range) - 1]); $i++) {
                         if (($i) % $match != 0) {
                             $range[count($range) - 1][$i] = -1;
                         }
                     }
-                    $inrange = false;
+                    $instep = false;
                 } else if ($inrange) {
                     if (count($range)) {
                         $range[count($range) - 1] = range($last, $match);
                     }
                     $inrange = false;
                 } else {
-                    if ($match >= $min && $match <= $max) {
-                        array_push($range, $match);
-                    }
+                    array_push($range, $match);
                     $last = $match;
                 }
             }
         }
 
+        // If inrange or instep were not processed, there is a syntax error.
+        // Cleanup any existing values to show up the error.
+        if ($inrange || $instep) {
+            return [];
+        }
+
         // Flatten the result.
         $result = array();
         foreach ($range as $r) {
@@ -348,41 +478,82 @@ abstract class scheduled_task extends task_base {
 
     /**
      * Calculate when this task should next be run based on the schedule.
+     *
+     * @param int $now Current time, for testing (leave 0 to use default time)
      * @return int $nextruntime.
      */
-    public function get_next_scheduled_time() {
-        global $CFG;
-
-        $validminutes = $this->eval_cron_field($this->minute, self::MINUTEMIN, self::MINUTEMAX);
-        $validhours = $this->eval_cron_field($this->hour, self::HOURMIN, self::HOURMAX);
+    public function get_next_scheduled_time(int $now = 0): int {
+        if (!$now) {
+            $now = time();
+        }
 
         // We need to change to the server timezone before using php date() functions.
         \core_date::set_default_server_timezone();
 
-        $daysinmonth = date("t");
-        $validdays = $this->eval_cron_field($this->day, 1, $daysinmonth);
-        $validdaysofweek = $this->eval_cron_field($this->dayofweek, 0, 7);
-        $validmonths = $this->eval_cron_field($this->month, 1, 12);
-        $nextvalidyear = date('Y');
+        $validminutes = $this->get_valid(self::FIELD_MINUTE);
+        $validhours = $this->get_valid(self::FIELD_HOUR);
+        $validdays = $this->get_valid(self::FIELD_DAY);
+        $validdaysofweek = $this->get_valid(self::FIELD_DAYOFWEEK);
+        $validmonths = $this->get_valid(self::FIELD_MONTH);
 
-        $currentminute = date("i") + 1;
-        $currenthour = date("H");
-        $currentday = date("j");
-        $currentmonth = date("n");
-        $currentdayofweek = date("w");
+        // If any of the fields contain no valid data then the task will never run.
+        if (!$validminutes || !$validhours || !$validdays || !$validdaysofweek || !$validmonths) {
+            return self::NEVER_RUN_TIME;
+        }
 
-        $nextvalidminute = $this->next_in_list($currentminute, $validminutes);
-        if ($nextvalidminute < $currentminute) {
-            $currenthour += 1;
+        $result = self::get_next_scheduled_time_inner($now, $validminutes, $validhours, $validdays, $validdaysofweek, $validmonths);
+        return $result;
+    }
+
+    /**
+     * Recursively calculate the next valid time for this task.
+     *
+     * @param int $now Start time
+     * @param array $validminutes Valid minutes
+     * @param array $validhours Valid hours
+     * @param array $validdays Valid days
+     * @param array $validdaysofweek Valid days of week
+     * @param array $validmonths Valid months
+     * @param int $originalyear Zero for first call, original year for recursive calls
+     * @return int Next run time
+     */
+    protected function get_next_scheduled_time_inner(int $now, array $validminutes, array $validhours,
+            array $validdays, array $validdaysofweek, array $validmonths, int $originalyear = 0) {
+        $currentyear = (int)date('Y', $now);
+        if ($originalyear) {
+            // In recursive calls, check we didn't go more than 8 years ahead, that indicates the
+            // user has chosen an impossible date. 8 years is the maximum time, considering a task
+            // set to run on 29 February over a century boundary when a leap year is skipped.
+            if ($currentyear - $originalyear > 8) {
+                // Use this time if it's never going to happen.
+                return self::NEVER_RUN_TIME;
+            }
+            $firstyear = $originalyear;
+        } else {
+            $firstyear = $currentyear;
         }
-        $nextvalidhour = $this->next_in_list($currenthour, $validhours);
-        if ($nextvalidhour < $currenthour) {
-            $currentdayofweek += 1;
-            $currentday += 1;
+        $currentmonth = (int)date('n', $now);
+
+        // Evaluate month first.
+        $nextvalidmonth = $this->next_in_list($currentmonth, $validmonths);
+        if ($nextvalidmonth < $currentmonth) {
+            $currentyear += 1;
         }
-        $nextvaliddayofmonth = $this->next_in_list($currentday, $validdays);
-        $nextvaliddayofweek = $this->next_in_list($currentdayofweek, $validdaysofweek);
+        // If we moved to another month, set the current time to start of month, and restart calculations.
+        if ($nextvalidmonth !== $currentmonth) {
+            $newtime = strtotime($currentyear . '-' . $nextvalidmonth . '-01 00:00');
+            return $this->get_next_scheduled_time_inner($newtime, $validminutes, $validhours, $validdays,
+                    $validdaysofweek, $validmonths, $firstyear);
+        }
+
+        // Special handling for dayofmonth vs dayofweek (see man 5 cron). If both are specified, then
+        // it is ok to continue when either matches. If only one is specified then it must match.
+        $currentday = (int)date("j", $now);
+        $currentdayofweek = (int)date("w", $now);
+        $nextvaliddayofmonth = self::next_in_list($currentday, $validdays);
+        $nextvaliddayofweek = self::next_in_list($currentdayofweek, $validdaysofweek);
         $daysincrementbymonth = $nextvaliddayofmonth - $currentday;
+        $daysinmonth = (int)date('t', $now);
         if ($nextvaliddayofmonth < $currentday) {
             $daysincrementbymonth += $daysinmonth;
         }
@@ -392,48 +563,94 @@ abstract class scheduled_task extends task_base {
             $daysincrementbyweek += 7;
         }
 
-        // Special handling for dayofmonth vs dayofweek:
-        // if either field is * - use the other field
-        // otherwise - choose the soonest (see man 5 cron).
         if ($this->dayofweek == '*') {
             $daysincrement = $daysincrementbymonth;
         } else if ($this->day == '*') {
             $daysincrement = $daysincrementbyweek;
         } else {
             // Take the smaller increment of days by month or week.
-            $daysincrement = $daysincrementbymonth;
-            if ($daysincrementbyweek < $daysincrementbymonth) {
-                $daysincrement = $daysincrementbyweek;
+            $daysincrement = min($daysincrementbymonth, $daysincrementbyweek);
+        }
+
+        // If we moved day, recurse using new start time.
+        if ($daysincrement != 0) {
+            $newtime = strtotime($currentyear . '-' . $currentmonth . '-' . $currentday .
+                    ' 00:00 +' . $daysincrement . ' days');
+            return $this->get_next_scheduled_time_inner($newtime, $validminutes, $validhours, $validdays,
+                    $validdaysofweek, $validmonths, $firstyear);
+        }
+
+        $currenthour = (int)date('H', $now);
+        $nextvalidhour = $this->next_in_list($currenthour, $validhours);
+        if ($nextvalidhour != $currenthour) {
+            if ($nextvalidhour < $currenthour) {
+                $offset = ' +1 day';
+            } else {
+                $offset = '';
             }
+            $newtime = strtotime($currentyear . '-' . $currentmonth . '-' . $currentday . ' ' . $nextvalidhour .
+                    ':00' . $offset);
+            return $this->get_next_scheduled_time_inner($newtime, $validminutes, $validhours, $validdays,
+                $validdaysofweek, $validmonths, $firstyear);
         }
 
-        $nextvaliddayofmonth = $currentday + $daysincrement;
-        if ($nextvaliddayofmonth > $daysinmonth) {
-            $currentmonth += 1;
-            $nextvaliddayofmonth -= $daysinmonth;
+        // Round time down to an exact minute because we need to use numeric calculations on it now.
+        // If we construct times based on all the components, it will mess up around DST changes
+        // (because there are two times with the same representation).
+        $now = intdiv($now, 60) * 60;
+
+        $currentminute = (int)date('i', $now);
+        $nextvalidminute = $this->next_in_list($currentminute, $validminutes);
+        if ($nextvalidminute == $currentminute && !$originalyear) {
+            // This is not a recursive call so time has not moved on at all yet. We can't use the
+            // same minute as now because it has already happened, it has to be at least one minute
+            // later, so update time and retry.
+            $newtime = $now + 60;
+            return $this->get_next_scheduled_time_inner($newtime, $validminutes, $validhours, $validdays,
+                $validdaysofweek, $validmonths, $firstyear);
         }
 
-        $nextvalidmonth = $this->next_in_list($currentmonth, $validmonths);
-        if ($nextvalidmonth < $currentmonth) {
-            $nextvalidyear += 1;
+        if ($nextvalidminute < $currentminute) {
+            // The time is in the next hour so we need to recurse. Don't use strtotime at this
+            // point because it will mess up around DST changes.
+            $minutesforward = $nextvalidminute + 60 - $currentminute;
+            $newtime = $now + $minutesforward * 60;
+            return $this->get_next_scheduled_time_inner($newtime, $validminutes, $validhours, $validdays,
+                $validdaysofweek, $validmonths, $firstyear);
         }
 
-        // Work out the next valid time.
-        $nexttime = mktime($nextvalidhour,
-                           $nextvalidminute,
-                           0,
-                           $nextvalidmonth,
-                           $nextvaliddayofmonth,
-                           $nextvalidyear);
-
-        return $nexttime;
+        // The next valid minute is in the same hour so it must be valid according to all other
+        // checks and we can finally return it.
+        return $now + ($nextvalidminute - $currentminute) * 60;
     }
 
     /**
-     * Get a descriptive name for this task (shown to admins).
+     * Informs whether this task can be run.
      *
-     * @return string
+     * @return bool true when this task can be run. false otherwise.
      */
-    public abstract function get_name();
+    public function can_run(): bool {
+        return $this->is_component_enabled() || $this->get_run_if_component_disabled();
+    }
 
+    /**
+     * Checks whether the component and the task disabled flag enables to run this task.
+     * This do not checks whether the task manager allows running them or if the
+     * site allows tasks to "run now".
+     *
+     * @return bool true if task is enabled. false otherwise.
+     */
+    public function is_enabled(): bool {
+        return $this->can_run() && !$this->get_disabled();
+    }
+
+    /**
+     * Produces a valid id string to use as id attribute based on the given FQCN class name.
+     *
+     * @param string $classname FQCN of a task.
+     * @return string valid string to be used as id attribute.
+     */
+    public static function get_html_id(string $classname): string {
+        return str_replace('\\', '-', ltrim($classname, '\\'));
+    }
 }
