@@ -30,6 +30,7 @@ use cache_helper;
 use lang_string;
 use mod_bigbluebuttonbn\local\config;
 use mod_bigbluebuttonbn\local\helpers\roles;
+use mod_bigbluebuttonbn\local\proxy\bigbluebutton_proxy;
 
 /**
  * The mod_bigbluebuttonbn settings helper
@@ -50,6 +51,9 @@ class settings {
     /** @var string The name of the section */
     private $section;
 
+    /** @var string The parent name */
+    private $parent = "modbigbluebuttonbnfolder";
+
     /** @var string The section name prefix */
     private $sectionnameprefix = "mod_bigbluebuttonbn";
 
@@ -66,7 +70,7 @@ class settings {
         $this->section = $categoryname;
 
         $modbigbluebuttobnfolder = new admin_category(
-            $categoryname,
+            $this->parent,
             new lang_string('pluginname', 'mod_bigbluebuttonbn'),
             $module->is_enabled() === false
         );
@@ -74,15 +78,16 @@ class settings {
         $admin->add('modsettings', $modbigbluebuttobnfolder);
 
         $mainsettings = $this->add_general_settings();
-        $admin->add($categoryname, $mainsettings);
+        $admin->add($this->parent, $mainsettings);
     }
 
     /**
      * Add all settings.
      */
     public function add_all_settings(): void {
+        // Renders settings for welcome messages.
+        $this->add_defaultmessages_settings();
         // Evaluates if recordings are enabled for the Moodle site.
-
         // Renders settings for record feature.
         $this->add_record_settings();
         // Renders settings for import recordings.
@@ -131,8 +136,10 @@ class settings {
      * @throws \coding_exception
      */
     protected function add_general_settings(): admin_settingpage {
+        global $CFG;
+
         $settingsgeneral = new admin_settingpage(
-            "{$this->sectionnameprefix}_general",
+            $this->section,
             get_string('config_general', 'bigbluebuttonbn'),
             'moodle/site:config',
             !((boolean) setting_validator::section_general_shown()) && ($this->moduleenabled)
@@ -141,7 +148,17 @@ class settings {
             // Configuration for BigBlueButton.
             $item = new admin_setting_heading('bigbluebuttonbn_config_general',
                 '',
-                get_string('config_general_description', 'bigbluebuttonbn'));
+                get_string('config_general_description', 'bigbluebuttonbn')
+            );
+
+            if (empty($CFG->bigbluebuttonbn_default_dpa_accepted)) {
+                $settingsgeneral->add(new admin_setting_configcheckbox(
+                    'bigbluebuttonbn_default_dpa_accepted',
+                    get_string('acceptdpa', 'mod_bigbluebuttonbn'),
+                    get_string('enablingbigbluebuttondpainfo', 'mod_bigbluebuttonbn', config::DEFAULT_DPA_URL),
+                    0
+                ));
+            }
 
             $settingsgeneral->add($item);
             $item = new admin_setting_configtext(
@@ -174,13 +191,51 @@ class settings {
                 $item,
                 $settingsgeneral
             );
-            $settingsgeneral->add($item);
+            $item = new \admin_setting_description(
+                'bigbluebuttonbn_dpa_info',
+                '',
+                get_string('config_dpa_note', 'bigbluebuttonbn', config::DEFAULT_DPA_URL),
+            );
+            $this->add_conditional_element(
+                'dpa_info',
+                $item,
+                $settingsgeneral
+            );
+            $item = new admin_setting_configtext(
+                'bigbluebuttonbn_poll_interval',
+                get_string('config_poll_interval', 'bigbluebuttonbn'),
+                get_string('config_poll_interval_description', 'bigbluebuttonbn'),
+                bigbluebutton_proxy::DEFAULT_POLL_INTERVAL,
+                PARAM_INT
+            );
+            $this->add_conditional_element(
+                'poll_interval',
+                $item,
+                $settingsgeneral
+            );
+        }
+        return $settingsgeneral;
+    }
+
+    /**
+     * Helper function renders default messages settings if the feature is enabled.
+     */
+    protected function add_defaultmessages_settings(): void {
+        // Configuration for 'default messages' feature.
+        $defaultmessagessetting = new admin_settingpage(
+            "{$this->sectionnameprefix}_default_messages",
+            get_string('config_default_messages', 'bigbluebuttonbn'),
+            'moodle/site:config',
+            !((boolean) setting_validator::section_default_messages_shown()) && ($this->moduleenabled)
+        );
+
+        if ($this->admin->fulltree) {
             $item = new admin_setting_heading(
                 'bigbluebuttonbn_config_default_messages',
-                get_string('config_default_messages', 'bigbluebuttonbn'),
+                '',
                 get_string('config_default_messages_description', 'bigbluebuttonbn')
             );
-            $settingsgeneral->add($item);
+            $defaultmessagessetting->add($item);
             $item = new admin_setting_configtextarea(
                 'bigbluebuttonbn_welcome_default',
                 get_string('config_welcome_default', 'bigbluebuttonbn'),
@@ -191,9 +246,8 @@ class settings {
             $this->add_conditional_element(
                 'welcome_default',
                 $item,
-                $settingsgeneral
+                $defaultmessagessetting
             );
-            $settingsgeneral->add($item);
             $item = new admin_setting_configcheckbox(
                 'bigbluebuttonbn_welcome_editable',
                 get_string('config_welcome_editable', 'bigbluebuttonbn'),
@@ -203,10 +257,11 @@ class settings {
             $this->add_conditional_element(
                 'welcome_editable',
                 $item,
-                $settingsgeneral
+                $defaultmessagessetting
             );
         }
-        return $settingsgeneral;
+        $this->admin->add($this->parent, $defaultmessagessetting);
+
     }
 
     /**
@@ -309,7 +364,7 @@ class settings {
                 $recordingsetting
             );
         }
-        $this->admin->add($this->section, $recordingsetting);
+        $this->admin->add($this->parent, $recordingsetting);
     }
 
     /**
@@ -354,7 +409,7 @@ class settings {
                 $importrecordingsettings
             );
         }
-        $this->admin->add($this->section, $importrecordingsettings);
+        $this->admin->add($this->parent, $importrecordingsettings);
     }
 
     /**
@@ -443,13 +498,13 @@ class settings {
                 $showrecordingsettings
             );
             $item = new admin_setting_configcheckbox(
-                'bigbluebuttonbn_recordings_sortorder',
-                get_string('config_recordings_sortorder', 'bigbluebuttonbn'),
-                get_string('config_recordings_sortorder_description', 'bigbluebuttonbn'),
+                'bigbluebuttonbn_recordings_asc_sort',
+                get_string('config_recordings_asc_sort', 'bigbluebuttonbn'),
+                get_string('config_recordings_asc_sort_description', 'bigbluebuttonbn'),
                 0
             );
             $this->add_conditional_element(
-                'recordings_sortorder',
+                'recordings_asc_sort',
                 $item,
                 $showrecordingsettings
             );
@@ -465,7 +520,7 @@ class settings {
                 $showrecordingsettings
             );
         }
-        $this->admin->add($this->section, $showrecordingsettings);
+        $this->admin->add($this->parent, $showrecordingsettings);
     }
 
     /**
@@ -534,7 +589,7 @@ class settings {
                 $waitmoderatorsettings
             );
         }
-        $this->admin->add($this->section, $waitmoderatorsettings);
+        $this->admin->add($this->parent, $waitmoderatorsettings);
     }
 
     /**
@@ -568,7 +623,7 @@ class settings {
                 $voicebridgesettings
             );
         }
-        $this->admin->add($this->section, $voicebridgesettings);
+        $this->admin->add($this->parent, $voicebridgesettings);
     }
 
     /**
@@ -622,7 +677,7 @@ class settings {
 
             $preuploadsettings->add($filemanager);
         }
-        $this->admin->add($this->section, $preuploadsettings);
+        $this->admin->add($this->parent, $preuploadsettings);
     }
 
     /**
@@ -668,7 +723,7 @@ class settings {
                 $userlimitsettings
             );
         }
-        $this->admin->add($this->section, $userlimitsettings);
+        $this->admin->add($this->parent, $userlimitsettings);
     }
 
     /**
@@ -709,7 +764,7 @@ class settings {
                 $participantsettings
             );
         }
-        $this->admin->add($this->section, $participantsettings);
+        $this->admin->add($this->parent, $participantsettings);
     }
 
     /**
@@ -754,7 +809,7 @@ class settings {
                 $muteonstartsetting
             );
         }
-        $this->admin->add($this->section, $muteonstartsetting);
+        $this->admin->add($this->parent, $muteonstartsetting);
     }
 
     /**
@@ -775,9 +830,8 @@ class settings {
             $this->add_lock_setting_from_name('disablepublicchat', $lockingsetting);
             $this->add_lock_setting_from_name('disablenote', $lockingsetting);
             $this->add_lock_setting_from_name('hideuserlist', $lockingsetting);
-            $this->add_lock_setting_from_name('lockonjoin', $lockingsetting);
         }
-        $this->admin->add($this->section, $lockingsetting);
+        $this->admin->add($this->parent, $lockingsetting);
     }
 
     /**
@@ -847,7 +901,7 @@ class settings {
                 $extendedcapabilitiessetting
             );
         }
-        $this->admin->add($this->section, $extendedcapabilitiessetting);
+        $this->admin->add($this->parent, $extendedcapabilitiessetting);
         // Configuration for extended BN capabilities should go here.
     }
 
@@ -882,8 +936,20 @@ class settings {
                 $item,
                 $experimentalfeaturessetting
             );
+            // UI for 'register meeting events' feature.
+            $item = new admin_setting_configcheckbox(
+                'bigbluebuttonbn_guestaccess_enabled',
+                get_string('config_guestaccess_enabled', 'bigbluebuttonbn'),
+                get_string('config_guestaccess_enabled_description', 'bigbluebuttonbn'),
+                0
+            );
+            $this->add_conditional_element(
+                'guestaccess_enabled',
+                $item,
+                $experimentalfeaturessetting
+            );
         }
-        $this->admin->add($this->section, $experimentalfeaturessetting);
+        $this->admin->add($this->parent, $experimentalfeaturessetting);
     }
 
     /**
