@@ -54,10 +54,8 @@ class qtype_calculatedmulti_edit_form extends question_edit_form {
             if (isset($this->question->id)) {
                 // Remove prefix #{..}# if exists.
                 $this->initialname = $question->name;
-                $regs= array();
-                if (preg_match('~#\{([^[:space:]]*)#~', $question->name , $regs)) {
-                    $question->name = str_replace($regs[0], '', $question->name);
-                };
+                $question->name = question_bank::get_qtype('calculated')
+                        ->clean_technical_prefix_from_question_name($question->name);
             }
         }
         parent::__construct($submiturl, $question, $category, $contexts, $formeditable);
@@ -74,7 +72,7 @@ class qtype_calculatedmulti_edit_form extends question_edit_form {
         $answeroptions[] = $mform->createElement('text', 'answer',
                 $label, array('size' => 50));
         $answeroptions[] = $mform->createElement('select', 'fraction',
-                get_string('grade'), $gradeoptions);
+                get_string('gradenoun'), $gradeoptions);
         $repeated[] = $mform->createElement('group', 'answeroptions',
                  $label, $answeroptions, null, false);
 
@@ -128,7 +126,7 @@ class qtype_calculatedmulti_edit_form extends question_edit_form {
         if (isset($this->question->id)) {
             $mform->insertElementBefore($mform->createElement('static', 'initialname',
                     get_string('questionstoredname', 'qtype_calculated'),
-                    format_string($this->initialname, true, array('context' => $this->context))), 'name');
+                    format_string($this->initialname)), 'name');
         };
         $addfieldsname = 'updatecategory';
         $addstring = get_string('updatecategory', 'qtype_calculated');
